"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBodyText = exports.isMediaBody = exports.isTextBody = exports.MEDIA_TYPES = void 0;
const generic_types_1 = require("./generic-types");
exports.MEDIA_TYPES = ['animation', 'audio', 'document', 'photo', 'video'];
function isKnownMediaType(type) {
    if (typeof type !== 'string') {
        return false;
    }
    return exports.MEDIA_TYPES.includes(type);
}
function isTextBody(body) {
    if (!body) {
        return false;
    }
    if (typeof body === 'string') {
        return true;
    }
    if (!generic_types_1.isObject(body)) {
        return false;
    }
    if (body.type !== undefined) {
        return false;
    }
    return generic_types_1.hasTruthyKey(body, 'text');
}
exports.isTextBody = isTextBody;
function isMediaBody(body) {
    if (!generic_types_1.isObject(body)) {
        return false;
    }
    if (!isKnownMediaType(body.type)) {
        return false;
    }
    return generic_types_1.hasTruthyKey(body, 'media');
}
exports.isMediaBody = isMediaBody;
function getBodyText(body) {
    return typeof body === 'string' ? body : body.text;
}
exports.getBodyText = getBodyText;
//# sourceMappingURL=body.js.map